==> servicecatalog-1.0.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/servicecatalog/CfnLaunchTemplateConstraintProps.java <==
package software.amazon.awscdk.services.servicecatalog;

/**
 * Properties for defining a `AWS::ServiceCatalog::LaunchTemplateConstraint`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.0 (build a586a1a)", date = "2019-07-11T14:10:48.397Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnLaunchTemplateConstraintProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.PortfolioId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-portfolioid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getPortfolioId();
    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.ProductId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-productid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getProductId();
    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.Rules`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-rules
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getRules();
    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.AcceptLanguage`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-acceptlanguage
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getAcceptLanguage();
    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.Description`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-description
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getDescription();

    /**
     * @return a {@link Builder} of {@link CfnLaunchTemplateConstraintProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnLaunchTemplateConstraintProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        private java.lang.String _portfolioId;
        private java.lang.String _productId;
        private java.lang.String _rules;
        @javax.annotation.Nullable
        private java.lang.String _acceptLanguage;
        @javax.annotation.Nullable
        private java.lang.String _description;

        /**
         * Sets the value of PortfolioId
         * @param value `AWS::ServiceCatalog::LaunchTemplateConstraint.PortfolioId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withPortfolioId(final java.lang.String value) {
            this._portfolioId = java.util.Objects.requireNonNull(value, "portfolioId is required");
            return this;
        }
        /**
         * Sets the value of ProductId
         * @param value `AWS::ServiceCatalog::LaunchTemplateConstraint.ProductId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withProductId(final java.lang.String value) {
            this._productId = java.util.Objects.requireNonNull(value, "productId is required");
            return this;
        }
        /**
         * Sets the value of Rules
         * @param value `AWS::ServiceCatalog::LaunchTemplateConstraint.Rules`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withRules(final java.lang.String value) {
            this._rules = java.util.Objects.requireNonNull(value, "rules is required");
            return this;
        }
        /**
         * Sets the value of AcceptLanguage
         * @param value `AWS::ServiceCatalog::LaunchTemplateConstraint.AcceptLanguage`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withAcceptLanguage(@javax.annotation.Nullable final java.lang.String value) {
            this._acceptLanguage = value;
            return this;
        }
        /**
         * Sets the value of Description
         * @param value `AWS::ServiceCatalog::LaunchTemplateConstraint.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withDescription(@javax.annotation.Nullable final java.lang.String value) {
            this._description = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnLaunchTemplateConstraintProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public CfnLaunchTemplateConstraintProps build() {
            return new CfnLaunchTemplateConstraintProps() {
                private final java.lang.String $portfolioId = java.util.Objects.requireNonNull(_portfolioId, "portfolioId is required");
                private final java.lang.String $productId = java.util.Objects.requireNonNull(_productId, "productId is required");
                private final java.lang.String $rules = java.util.Objects.requireNonNull(_rules, "rules is required");
                @javax.annotation.Nullable
                private final java.lang.String $acceptLanguage = _acceptLanguage;
                @javax.annotation.Nullable
                private final java.lang.String $description = _description;

                @Override
                public java.lang.String getPortfolioId() {
                    return this.$portfolioId;
                }

                @Override
                public java.lang.String getProductId() {
                    return this.$productId;
                }

                @Override
                public java.lang.String getRules() {
                    return this.$rules;
                }

                @Override
                public java.lang.String getAcceptLanguage() {
                    return this.$acceptLanguage;
                }

                @Override
                public java.lang.String getDescription() {
                    return this.$description;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("portfolioId", om.valueToTree(this.getPortfolioId()));
                    obj.set("productId", om.valueToTree(this.getProductId()));
                    obj.set("rules", om.valueToTree(this.getRules()));
                    if (this.getAcceptLanguage() != null) {
                        obj.set("acceptLanguage", om.valueToTree(this.getAcceptLanguage()));
                    }
                    if (this.getDescription() != null) {
                        obj.set("description", om.valueToTree(this.getDescription()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.servicecatalog.CfnLaunchTemplateConstraintProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::ServiceCatalog::LaunchTemplateConstraint.PortfolioId`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-portfolioid
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getPortfolioId() {
            return this.jsiiGet("portfolioId", java.lang.String.class);
        }

        /**
         * `AWS::ServiceCatalog::LaunchTemplateConstraint.ProductId`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-productid
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getProductId() {
            return this.jsiiGet("productId", java.lang.String.class);
        }

        /**
         * `AWS::ServiceCatalog::LaunchTemplateConstraint.Rules`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-rules
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getRules() {
            return this.jsiiGet("rules", java.lang.String.class);
        }

        /**
         * `AWS::ServiceCatalog::LaunchTemplateConstraint.AcceptLanguage`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-acceptlanguage
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getAcceptLanguage() {
            return this.jsiiGet("acceptLanguage", java.lang.String.class);
        }

        /**
         * `AWS::ServiceCatalog::LaunchTemplateConstraint.Description`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-description
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getDescription() {
            return this.jsiiGet("description", java.lang.String.class);
        }
    }
}

==> servicecatalog-1.1.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/servicecatalog/CfnLaunchTemplateConstraintProps.java <==
package software.amazon.awscdk.services.servicecatalog;

/**
 * Properties for defining a `AWS::ServiceCatalog::LaunchTemplateConstraint`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.2 (build e881f16)", date = "2019-07-19T19:04:13.280Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnLaunchTemplateConstraintProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.PortfolioId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-portfolioid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getPortfolioId();
    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.ProductId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-productid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getProductId();
    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.Rules`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-rules
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getRules();
    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.AcceptLanguage`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-acceptlanguage
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getAcceptLanguage();
    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.Description`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-description
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getDescription();

    /**
     * @return a {@link Builder} of {@link CfnLaunchTemplateConstraintProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnLaunchTemplateConstraintProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Builder {
        private java.lang.String _portfolioId;
        private java.lang.String _productId;
        private java.lang.String _rules;
        @javax.annotation.Nullable
        private java.lang.String _acceptLanguage;
        @javax.annotation.Nullable
        private java.lang.String _description;

        /**
         * Sets the value of PortfolioId
         * @param value `AWS::ServiceCatalog::LaunchTemplateConstraint.PortfolioId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withPortfolioId(final java.lang.String value) {
            this._portfolioId = java.util.Objects.requireNonNull(value, "portfolioId is required");
            return this;
        }
        /**
         * Sets the value of ProductId
         * @param value `AWS::ServiceCatalog::LaunchTemplateConstraint.ProductId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withProductId(final java.lang.String value) {
            this._productId = java.util.Objects.requireNonNull(value, "productId is required");
            return this;
        }
        /**
         * Sets the value of Rules
         * @param value `AWS::ServiceCatalog::LaunchTemplateConstraint.Rules`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withRules(final java.lang.String value) {
            this._rules = java.util.Objects.requireNonNull(value, "rules is required");
            return this;
        }
        /**
         * Sets the value of AcceptLanguage
         * @param value `AWS::ServiceCatalog::LaunchTemplateConstraint.AcceptLanguage`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withAcceptLanguage(@javax.annotation.Nullable final java.lang.String value) {
            this._acceptLanguage = value;
            return this;
        }
        /**
         * Sets the value of Description
         * @param value `AWS::ServiceCatalog::LaunchTemplateConstraint.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withDescription(@javax.annotation.Nullable final java.lang.String value) {
            this._description = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnLaunchTemplateConstraintProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnLaunchTemplateConstraintProps build() {
            return new CfnLaunchTemplateConstraintProps() {
                private final java.lang.String $portfolioId = java.util.Objects.requireNonNull(_portfolioId, "portfolioId is required");
                private final java.lang.String $productId = java.util.Objects.requireNonNull(_productId, "productId is required");
                private final java.lang.String $rules = java.util.Objects.requireNonNull(_rules, "rules is required");
                @javax.annotation.Nullable
                private final java.lang.String $acceptLanguage = _acceptLanguage;
                @javax.annotation.Nullable
                private final java.lang.String $description = _description;

                @Override
                public java.lang.String getPortfolioId() {
                    return this.$portfolioId;
                }

                @Override
                public java.lang.String getProductId() {
                    return this.$productId;
                }

                @Override
                public java.lang.String getRules() {
                    return this.$rules;
                }

                @Override
                public java.lang.String getAcceptLanguage() {
                    return this.$acceptLanguage;
                }

                @Override
                public java.lang.String getDescription() {
                    return this.$description;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("portfolioId", om.valueToTree(this.getPortfolioId()));
                    obj.set("productId", om.valueToTree(this.getProductId()));
                    obj.set("rules", om.valueToTree(this.getRules()));
                    if (this.getAcceptLanguage() != null) {
                        obj.set("acceptLanguage", om.valueToTree(this.getAcceptLanguage()));
                    }
                    if (this.getDescription() != null) {
                        obj.set("description", om.valueToTree(this.getDescription()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.servicecatalog.CfnLaunchTemplateConstraintProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::ServiceCatalog::LaunchTemplateConstraint.PortfolioId`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-portfolioid
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public java.lang.String getPortfolioId() {
            return this.jsiiGet("portfolioId", java.lang.String.class);
        }

        /**
         * `AWS::ServiceCatalog::LaunchTemplateConstraint.ProductId`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-productid
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public java.lang.String getProductId() {
            return this.jsiiGet("productId", java.lang.String.class);
        }

        /**
         * `AWS::ServiceCatalog::LaunchTemplateConstraint.Rules`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-rules
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public java.lang.String getRules() {
            return this.jsiiGet("rules", java.lang.String.class);
        }

        /**
         * `AWS::ServiceCatalog::LaunchTemplateConstraint.AcceptLanguage`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-acceptlanguage
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getAcceptLanguage() {
            return this.jsiiGet("acceptLanguage", java.lang.String.class);
        }

        /**
         * `AWS::ServiceCatalog::LaunchTemplateConstraint.Description`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-description
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getDescription() {
            return this.jsiiGet("description", java.lang.String.class);
        }
    }
}
